<?php

namespace Litecms\ShippingMethod\Providers;

use Illuminate\Support\ServiceProvider;

class ShippingMethodServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'shipping_method');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'shipping_method');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.shipping_method', function ($app) {
            return $this->app->make('Litecms\ShippingMethod\ShippingMethod');
        });

                // Bind ShippingMethod to repository
        $this->app->bind(
            'Litecms\ShippingMethod\Interfaces\ShippingMethodRepositoryInterface',
            \Litecms\ShippingMethod\Repositories\Eloquent\ShippingMethodRepository::class
        );

        $this->app->register(\Litecms\ShippingMethod\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\ShippingMethod\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.shipping_method'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/shipping_method.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/shipping_method')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/shipping_method')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
